@@ -304,11 +304,11 @@ gw_control_load_pdf (GPdfWindow *gpdf_window, const char *uri)
 	Bonobo_PersistFile_load (persist, uri, &ev);
 
 	if (BONOBO_EX (&ev))
-		goto error_stream;
+		goto error_persist_file;
 
 	success = TRUE;		
 
-error_stream:
+error_persist_file:
 	bonobo_object_release_unref (persist, &ev);
 error_persist:
 	CORBA_exception_free (&ev);
@@ -527,6 +527,7 @@ static gboolean
 gw_ask_for_uri (GPdfWindow *gpdf_window, gchar ***uri)
 {
 	GtkFileChooser *chooser;
+	GtkFileFilter *pdf_filter, *all_filter;
 	gboolean accepted = FALSE;
 
 	g_return_val_if_fail (GPDF_IS_NON_NULL_WINDOW (gpdf_window), FALSE);
@@ -541,7 +542,16 @@ gw_ask_for_uri (GPdfWindow *gpdf_window, gchar ***uri)
 								 NULL));
 	gtk_file_chooser_set_select_multiple (chooser, TRUE); 
 	gtk_window_set_modal (GTK_WINDOW (chooser), TRUE);
-
+	pdf_filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (pdf_filter, _("PDF Documents"));
+	gtk_file_filter_add_mime_type (pdf_filter, "application/pdf");
+	gtk_file_chooser_add_filter (chooser, pdf_filter);
+	all_filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (all_filter, _("All Files"));
+	gtk_file_filter_add_pattern (all_filter, "*");
+	gtk_file_chooser_add_filter (chooser, all_filter);
+	gtk_file_chooser_set_filter (chooser, pdf_filter);
+	
 	gtk_window_set_position (GTK_WINDOW (chooser), GTK_WIN_POS_MOUSE);
 
 	accepted = (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_OK);
@@ -699,7 +709,7 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data,
 			authors [i] = _(authors [i]);
 #endif
 
-		translators = _("translator_credits-PLEASE_ADD_YOURSELF_HERE");
+		translators = _("translator-credits");
 
 		tmp_str = g_strconcat ("Copyright \xc2\xa9 1996-2003 ",
 				     _("Glyph & Cog, LLC and authors"),
@@ -713,7 +723,7 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data,
 			authors,
 			documenters,
 			(strcmp (translators,
-				 "translator_credits-PLEASE_ADD_YOURSELF_HERE")
+				 "translator-credits")
 			 ? translators : NULL),
 			NULL);
 	
@@ -927,7 +937,7 @@ GtkWidget *gpdf_window_new (void)
 
 	gpdf_window = GPDF_WINDOW (g_object_new (GPDF_TYPE_WINDOW,
 						 "win_name", "gpdf",
-						 "title", _("GNOME PDF Viewer"),
+						 "title", _("PDF Viewer"),
 						 "default-width", 600,
 						 "default-height", 600,
 						 NULL));
