@@ -80,6 +80,7 @@ struct _GPdfBookmarksViewPrivate {
 	GdkPixbuf *stock_next_pixbuf; 
 	GdkPixbuf *stock_close_pixbuf; 
 	GdkPixbuf *stock_quit_pixbuf;
+	GdkPixbuf *stock_net_pixbuf;
 
 	GnomeUIInfo *popup_menu_uiinfo;
 	GtkWidget *popup_menu;
@@ -220,8 +221,8 @@ gpdf_bookmarks_view_class_init (GPdfBookmarksViewClass *klass)
 		gobject_class, PROP_VIEW,
 		g_param_spec_object (
 			"view",
-			_("Parent view"),
-			_("Parent view"),
+			"Parent view",
+			"Parent view",
 			GPDF_TYPE_VIEW, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
@@ -229,8 +230,8 @@ gpdf_bookmarks_view_class_init (GPdfBookmarksViewClass *klass)
 		gobject_class, PROP_CONTROL,
 		g_param_spec_object (
 			"control",
-			_("Parent control"),
-			_("Parent control"),
+			"Parent control",
+			"Parent control",
 			GPDF_TYPE_CONTROL, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
@@ -388,8 +389,12 @@ gpdf_bookmarks_view_construct (GPdfBookmarksView *bookmarks_view)
 			       GTK_STOCK_QUIT,
 			       GTK_ICON_SIZE_SMALL_TOOLBAR);
 
-	/* Build tools menu & items */
-	
+	/* Stock URI */
+	GPDF_RENDER_STOCK_ICON(bkwidget,
+			       priv->stock_net_pixbuf, 
+			       GTK_STOCK_NETWORK,
+			       GTK_ICON_SIZE_SMALL_TOOLBAR);
+
 }
 
 static void
@@ -481,7 +486,9 @@ gpdf_bookmarks_view_update_bkvisual (GtkTreeModel *model,
 	GPdfBookmarksView *bookmarks_view;
 	GPdfBookmarksViewPrivate *priv;
 	GValue page_nr_value = {0, };
-	gint page_nr; 
+	OutlineItem *anItem;
+	GValue an_item_value = {0, };
+	gint page_nr;
 	GdkPixbuf *bookmark_pixbuf = NULL;
 	gboolean page_displayed, is_expanded; 
 	
@@ -492,51 +499,61 @@ gpdf_bookmarks_view_update_bkvisual (GtkTreeModel *model,
 
 	priv = bookmarks_view->priv;
 
-	/* Get this bookmark page nr */
+	/* Get item to access action kind */
 	gtk_tree_model_get_value (model,
 				  iter,
-				  GPDF_BKVIEW_COLUMN5,
-				  &page_nr_value);
-	page_nr = g_value_get_int ((const GValue *)&page_nr_value);
+				  GPDF_BKVIEW_COLUMN4,
+				  &an_item_value);
+	anItem = (OutlineItem *) g_value_get_pointer ((const GValue *)&an_item_value);
 
-	/* Get its displayed/expanded states */
-	page_displayed = (page_nr == priv->current_page);
-	is_expanded = (gtk_tree_view_row_expanded (GTK_TREE_VIEW (priv->treeview),
-						   path));
-
-	/* And take pixbuf accordingly to set in store */
-	if (page_displayed) {
-		if (is_expanded)
-			bookmark_pixbuf = priv->stock_book_opened_mark_pixbuf; 
-		else
-			bookmark_pixbuf = priv->stock_book_closed_mark_pixbuf; 
-	}
-	else {
-		if (is_expanded)
-			bookmark_pixbuf = priv->stock_book_opened_pixbuf; 
-		else
-			bookmark_pixbuf = priv->stock_book_closed_pixbuf; 
-	}
-	gtk_tree_store_set (GTK_TREE_STORE (model), iter,
-			    GPDF_BKVIEW_COLUMN1, bookmark_pixbuf,
-			    -1);
-
-	/* For convinience, expand and scroll to current page bookmarks */
-	if (page_displayed)
+	if (anItem->getAction ()->getKind () == actionGoTo)
 	{
-		gtk_tree_view_expand_to_path (
-			GTK_TREE_VIEW (priv->treeview),
-			path);
+		/* Get this bookmark page nr */
+		gtk_tree_model_get_value (model,
+					  iter,
+					  GPDF_BKVIEW_COLUMN5,
+					  &page_nr_value);
+		page_nr = g_value_get_int ((const GValue *)&page_nr_value);
 		
-		gtk_tree_view_scroll_to_cell (
-			GTK_TREE_VIEW (priv->treeview),
-			path,
-			gtk_tree_view_get_column(
+		/* Get its displayed/expanded states */
+		page_displayed = (page_nr == priv->current_page);
+		is_expanded = (gtk_tree_view_row_expanded (GTK_TREE_VIEW (priv->treeview),
+							   path));
+		
+		/* And take pixbuf accordingly to set in store */
+		if (page_displayed) {
+			if (is_expanded)
+			  bookmark_pixbuf = priv->stock_book_opened_mark_pixbuf; 
+			else
+			  bookmark_pixbuf = priv->stock_book_closed_mark_pixbuf; 
+		}
+		else {
+			if (is_expanded)
+			  bookmark_pixbuf = priv->stock_book_opened_pixbuf; 
+			else
+			  bookmark_pixbuf = priv->stock_book_closed_pixbuf; 
+		}
+		gtk_tree_store_set (GTK_TREE_STORE (model), iter,
+				    GPDF_BKVIEW_COLUMN1, bookmark_pixbuf,
+				    -1);
+
+		/* For convinience, expand and scroll to current page bookmarks */
+		if (page_displayed)
+		{
+			gtk_tree_view_expand_to_path (
 				GTK_TREE_VIEW (priv->treeview),
-				GPDF_BKVIEW_COLUMN2),
-			TRUE, 0.0, 0.0); 
+				path);
+			
+			gtk_tree_view_scroll_to_cell (
+				GTK_TREE_VIEW (priv->treeview),
+				path,
+				gtk_tree_view_get_column(
+					GTK_TREE_VIEW (priv->treeview),
+					GPDF_BKVIEW_COLUMN2),
+				TRUE, 0.0, 0.0); 
+		}
 	}
-	
+		
 	return FALSE; 
 }
 
@@ -800,8 +817,9 @@ gpdf_bookmarks_view_flat_recurse_outlines (GPdfBookmarksView *bookmarks_view)
 	GdkPixbuf *bookmark_pixbuf = NULL; 
 	LinkAction *link_action = NULL;
 	LinkNamed *link_named = NULL;
-	LinkGoTo *link_goto;
-	LinkDest *link_dest; 
+	LinkGoTo *link_goto = NULL;
+	LinkDest *link_dest = NULL;
+	LinkURI *link_uri = NULL;
 	GString *named_dest; 
 	Ref page_ref;
 	gchar *action_name; 
@@ -901,18 +919,23 @@ gpdf_bookmarks_view_flat_recurse_outlines (GPdfBookmarksView *bookmarks_view)
 					bookmark_pixbuf = priv->stock_quit_pixbuf; 
 				} else {
 					g_warning ("Unimplemented named link action: %s", action_name);
-					pagestr = g_strdup ("Unknown"); 
+					pagestr = g_strdup_printf (_("** Unknown %s **"), action_name); 
 				}
 				if (page == -1)
 					pagestr = g_strdup (action_name); 
 				else if (page > 0)
 					pagestr = g_strdup_printf ("%d", page);
-				break; 
-				
+				break;
+
+			case actionURI:
+				link_uri = dynamic_cast <LinkURI *> (link_action);
+				pagestr = g_strdup (link_uri->getURI ()->getCString ());
+				bookmark_pixbuf = priv->stock_net_pixbuf;
+				break;
+
 			default:
-				pagestr = g_strdup ("Unknown"); 
-				g_warning ("Unkown link action type");
-				/* FIXME: free me later */
+				pagestr = g_strdup ("** Unknown action **"); 
+				g_warning ("Unkown link action type: %d", link_action->getKind ());
 			}
 
 			ratio = ((double)page/(double)priv->pdf_doc->getNumPages ()); 
