@@ -17,6 +17,7 @@
 #include <time.h>
 #include <unistd.h>
 #include "gpdf-control.h"
+#include "gpdf-control-private.h"
 #include "gpdf-stock-icons.h"
 #include "gpdf-view.h"
 #include "gpdf-bookmarks-view.h"
@@ -422,17 +423,31 @@ gpdf_control_private_get_annots_view (GPdfControl * control)
 }
 #endif
 
+void
+destroy_widget_unref_control (GtkWidget *widget, gint arg1, BonoboControl *control)
+{
+	g_return_if_fail (GTK_IS_WIDGET (widget));
+	g_return_if_fail (BONOBO_IS_CONTROL (control));
+
+	gtk_widget_destroy (widget);
+	bonobo_object_unref (BONOBO_OBJECT (control));
+}
+
 /* Create a HIG compliant dialog, display it and
    wait until response */
 void
 gpdf_control_private_error_dialog (GPdfControl * control,
 				   const gchar *header_text,
 				   const gchar *body_text,
-				   gboolean modal)
+				   gboolean modal,
+				   gboolean ref_parent)
 {
 	GtkWidget *dlg, *but;
 
 	g_return_if_fail (GPDF_IS_NON_NULL_CONTROL (control));
+	if (ref_parent)
+		bonobo_object_ref (BONOBO_OBJECT (control));
+
 	dlg = gpdf_hig_dialog_new (GTK_STOCK_DIALOG_ERROR,
 				   header_text,
 				   body_text,
@@ -446,10 +461,14 @@ gpdf_control_private_error_dialog (GPdfControl * control,
 	if (modal) {
 		gtk_dialog_run (GTK_DIALOG (dlg));
 		gtk_widget_destroy (dlg);
+		if (ref_parent)
+			bonobo_object_unref (BONOBO_OBJECT (control));
 	} else {
 		g_signal_connect (G_OBJECT (dlg), "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
+				  (ref_parent
+				   ? G_CALLBACK (destroy_widget_unref_control)
+				   : G_CALLBACK (gtk_widget_destroy)),
+				  control);
 		gtk_widget_show (dlg);
 	}		
 }
@@ -535,6 +554,7 @@ gpdf_control_private_display_help (BonoboControl *control,
 		gpdf_control_private_error_dialog (gpdf_control,
 						   _("Documentation Error"),
 						   msg,
+						   FALSE,
 						   FALSE);
 	}
 }
@@ -873,6 +893,7 @@ gpdf_control_no_postscript_printer_alert (GPdfControl *control,
 		control,
 		_("Printing is not supported on this printer."),
 		secondary,
+		FALSE,
 		FALSE);
 
 	g_free (secondary);
@@ -1926,7 +1947,7 @@ persist_file_loading_failed_cb (GPdfPersistFile *persist_file,
 		_("Loading of %s failed."),
 		gpdf_persist_file_get_current_uri (persist_file));
 
-	gpdf_control_private_error_dialog (control, primary, message, FALSE);
+	gpdf_control_private_error_dialog (control, primary, message, FALSE, TRUE);
 
 	g_free (primary);
 
@@ -2300,10 +2321,21 @@ gpdf_control_setup_view_widgets (GPdfControl *control)
 
 	gtk_box_pack_end (GTK_BOX (vbox), appbar, FALSE, FALSE, 0);
 
-	gpdf_view = gpdf_view_new (control);
-	control->priv->gpdf_view = gpdf_view;
+	control->priv->gpdf_view =
+	  gpdf_view =
+	    GTK_WIDGET (g_object_new (GPDF_TYPE_VIEW,
+				"aa", TRUE,	/* FIXME: a pref ? */
+				"control", control, 
+				NULL));
+
 	gtk_container_add (GTK_CONTAINER (sw), gpdf_view);
 
+	/* Workaround for 132489 */
+	gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (sw))
+		->step_increment = 10;
+	gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw))
+		->step_increment = 10;
+	
 	g_signal_connect (G_OBJECT (gpdf_view), "page_changed",
 			  G_CALLBACK (gc_page_changed_enable_page_buttons),
 			  control);
