@@ -212,8 +212,8 @@ gpdf_thumbnails_view_class_init (GPdfThumbnailsViewClass *klass)
 		gobject_class, PROP_VIEW,
 		g_param_spec_object (
 			"view",
-			_("Parent view"),
-			_("Parent view"),
+			"Parent view",
+			"Parent view",
 			GPDF_TYPE_VIEW, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
@@ -221,8 +221,8 @@ gpdf_thumbnails_view_class_init (GPdfThumbnailsViewClass *klass)
 		gobject_class, PROP_CONTROL,
 		g_param_spec_object (
 			"control",
-			_("Parent control"),
-			_("Parent control"),
+			"Parent control",
+			"Parent control",
 			GPDF_TYPE_CONTROL, 
 		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 
