@@ -99,6 +99,12 @@ enum {
 	LAST_SIGNAL
 };
 
+enum {
+	PROP_0,
+	PROP_CONTROL,
+	PROP_PDFDOC	  
+};
+
 static guint gpdf_view_signals [LAST_SIGNAL];
 
 
@@ -378,7 +384,8 @@ gpdf_view_link_action_uri (GPdfView *gpdf_view, LinkURI *link_uri)
 					gpdf_control_private_error_dialog (gpdf_view->priv->parent, 
 									   _("Application Launch Failure!"),
 									   msg,
-									   TRUE);
+									   TRUE,
+									   FALSE);
 					g_free (msg);
 				}
 			}
@@ -472,8 +479,8 @@ gpdf_view_link_entered_cb (GPdfLinksCanvasLayer *links_layer,
 	    switch (action->getKind ()) {
 	      case actionGoTo:
 	      {
-		  LinkGoTo *link_goto;
-		  LinkDest *link_dest;
+		  LinkGoTo *link_goto = NULL;
+		  LinkDest *link_dest = NULL;
 		  GString *named_dest;
 		  Ref page_ref;
 		  guint page = 0;
@@ -503,8 +510,8 @@ gpdf_view_link_entered_cb (GPdfLinksCanvasLayer *links_layer,
 	      }
 	      case actionGoToR:
 	      {
-		  LinkGoToR *link_gotor;
-		  LinkDest *link_dest;
+		  LinkGoToR *link_gotor = NULL;
+		  LinkDest *link_dest = NULL;
 		  GString *named_dest;
 		  Ref page_ref;
 		  guint page = 0;
@@ -546,7 +553,7 @@ gpdf_view_link_entered_cb (GPdfLinksCanvasLayer *links_layer,
 	      }
 	      case actionURI:
 	      {
-		  LinkURI *link_uri;
+		  LinkURI *link_uri = NULL;
 		  
 		  link_uri = dynamic_cast <LinkURI *> (action);
 		  text = g_strdup_printf (_("Browse %s"), link_uri->getURI ()->getCString ());
@@ -554,7 +561,7 @@ gpdf_view_link_entered_cb (GPdfLinksCanvasLayer *links_layer,
 	      }
 	      case actionNamed:
 	      {
-		  LinkNamed *link_named;
+		  LinkNamed *link_named = NULL;
 		  
 		  link_named = dynamic_cast <LinkNamed *> (action);
 		  text = g_strdup_printf (_("Action: %s"), link_named->getName ()->getCString ());
@@ -562,7 +569,7 @@ gpdf_view_link_entered_cb (GPdfLinksCanvasLayer *links_layer,
 	      }
 	      case actionMovie:
 	      {
-		  LinkMovie *link_movie;
+		  LinkMovie *link_movie = NULL;
 		  
 		  link_movie = dynamic_cast <LinkMovie *> (action);
 		  text = g_strdup_printf (_("Movie: %s"),
@@ -572,7 +579,7 @@ gpdf_view_link_entered_cb (GPdfLinksCanvasLayer *links_layer,
 	      case actionUnknown:
 	      default:
 	      {
-		  LinkUnknown *link_unknown;
+		  LinkUnknown *link_unknown = NULL;
 		  
 		  link_unknown = dynamic_cast <LinkUnknown *> (action);
 		  g_message ("Click on link: unknown Action");
@@ -1132,6 +1139,11 @@ gpdf_view_bookmark_selected (GPdfView   *gpdf_view,
 			gpdf_view_link_action_named (
 				gpdf_view, dynamic_cast <LinkNamed *> (link_action));
 			break;
+		 case actionURI:
+			gpdf_view_link_action_uri (
+				gpdf_view, dynamic_cast <LinkURI *> (link_action));
+			break;
+
 		default:
 			g_message ("Bookmark selection: unimplemented Action");
 			break;
@@ -1422,11 +1434,10 @@ gpdf_view_set_pdf_doc (GPdfView *gpdf_view, PDFDoc *pdf_doc)
 	priv = gpdf_view->priv;
 
 	gpdf_view_clear_history (gpdf_view);
-	/*
-	 * All PDFDocs in GPdf code are owned by a GPdfPersistStream,
-	 * so don't delete our old pdf_doc
-	 */
-	priv->pdf_doc = pdf_doc;
+
+	g_object_set (G_OBJECT (gpdf_view),
+		      "pdf_doc", pdf_doc,
+		      NULL);
 
 	priv->current_page = 0;
 	priv->output_dev->startDoc (pdf_doc->getXRef());
@@ -1509,67 +1520,55 @@ gpdf_view_finalize (GObject *object)
 }
 
 static void
-gpdf_view_class_init (GPdfViewClass *klass)
+gpdf_view_get_property (GObject *object, guint param_id,
+                        GValue *value, GParamSpec *pspec)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+	GPdfView *gpdf_view;
 
-	object_class->dispose = gpdf_view_dispose;
-	object_class->finalize = gpdf_view_finalize;
+	g_return_if_fail (GPDF_IS_VIEW (object));
 
-	widget_class->button_press_event = gpdf_view_button_press_event;
-	widget_class->button_release_event = gpdf_view_button_release_event;
-	widget_class->motion_notify_event = gpdf_view_motion_notify_event;
-	widget_class->key_press_event = gpdf_view_key_press_event;
+	gpdf_view = GPDF_VIEW (object);
 
-	gpdf_view_signals [ZOOM_CHANGED_SIGNAL] = g_signal_new (
-		"zoom_changed",
-		G_TYPE_FROM_CLASS (object_class),
-		G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (GPdfViewClass, zoom_changed),
-		NULL, NULL,
-		gpdf_marshal_VOID__DOUBLE,
-		G_TYPE_NONE, 1, G_TYPE_DOUBLE);
-
-	gpdf_view_signals [PAGE_CHANGED_SIGNAL] = g_signal_new (
-		"page_changed",
-		G_TYPE_FROM_CLASS (object_class),
-		G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (GPdfViewClass, page_changed),
-		NULL, NULL,
-		gpdf_marshal_VOID__INT,
-		G_TYPE_NONE, 1, G_TYPE_INT);
-
-	gpdf_view_signals [CLOSE_REQUESTED_SIGNAL] = g_signal_new (
-		"close_requested",
-		G_TYPE_FROM_CLASS (object_class),
-		G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (GPdfViewClass, close_requested),
-		NULL, NULL,
-		gpdf_marshal_VOID__VOID,
-		G_TYPE_NONE, 0);
-
-	gpdf_view_signals [QUIT_REQUESTED_SIGNAL] = g_signal_new (
-		"quit_requested",
-		G_TYPE_FROM_CLASS (object_class),
-		G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (GPdfViewClass, quit_requested),
-		NULL, NULL,
-		gpdf_marshal_VOID__VOID,
-		G_TYPE_NONE, 0);
+	switch (param_id)
+	{
+	      case PROP_PDFDOC:
+		g_value_set_pointer (value,
+				     (gpointer)gpdf_view->priv->pdf_doc);
+		break;
+	      default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
 }
 
 static void
-ggv_document_interface_init (GgvDocumentClass *klass, gpointer iface_data)
+gpdf_view_set_property (GObject *object, guint param_id,
+			const GValue *value, GParamSpec *pspec)
 {
-	klass->get_page_count = gpdf_view_get_page_count;
-	klass->get_page_names = gpdf_view_get_page_names;
-}
+	GPdfView *gpdf_view;
 
-static void
-gpdf_view_instance_init (GPdfView *gpdf_view)
+	g_return_if_fail (GPDF_IS_VIEW (object));
+
+	gpdf_view = GPDF_VIEW (object);
+
+	switch (param_id)
 {
-	gpdf_view->priv = g_new0 (GPdfViewPrivate, 1);
+	      case PROP_CONTROL:
+		gpdf_view->priv->parent =
+		  GPDF_CONTROL (g_value_get_object (value));
+		break;
+	      case PROP_PDFDOC:
+		/*
+		 * All PDFDocs in GPdf code are owned by a GPdfPersistStream,
+		 * so don't delete our old pdf_doc
+		 */
+		gpdf_view->priv->pdf_doc =
+		  (PDFDoc *)(g_value_get_pointer (value));
+		break;
+	      default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+		break;
+	}
 }
 
 static void
@@ -1652,11 +1651,21 @@ gpdf_view_setup_page_background (GPdfView *gpdf_view)
 	gpdf_view_page_background_hide (gpdf_view);
 }
 
-GPdfView *
-gpdf_view_construct (GPdfView *gpdf_view)
+static GObject *
+gpdf_view_constructor (GType type,
+		       guint n_construct_properties,
+		       GObjectConstructParam *construct_params)
 {
+	GObject *object;
+	GPdfView *gpdf_view;
 	GPdfViewPrivate *priv;
 
+	object = G_OBJECT_CLASS (parent_class)->constructor (
+		type, n_construct_properties, construct_params);
+
+	gpdf_view = GPDF_VIEW (object);
+	priv = gpdf_view->priv;
+
 	g_return_val_if_fail (GPDF_IS_NON_NULL_VIEW (gpdf_view), NULL);
 
 	gpdf_view_setup_page_background (gpdf_view);
@@ -1671,20 +1680,91 @@ gpdf_view_construct (GPdfView *gpdf_view)
 	priv->annots_cb = gpdf_annots_view_is_annot_displayed;
 #endif
 	
-	return gpdf_view;
+	return object;
 }
 
-GtkWidget *
-gpdf_view_new (GPdfControl *control)
+static void
+gpdf_view_class_init (GPdfViewClass *klass)
 {
-	GPdfView *gpdf_view;
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	gpdf_view = GPDF_VIEW (g_object_new (GPDF_TYPE_VIEW,
-					     "aa", TRUE,
-					     NULL));
-	gpdf_view->priv->parent = control; 
+	object_class->constructor = gpdf_view_constructor;
+	object_class->dispose = gpdf_view_dispose;
+	object_class->finalize = gpdf_view_finalize;
+	object_class->set_property = gpdf_view_set_property;
+	object_class->get_property = gpdf_view_get_property;
 
-	return GTK_WIDGET (gpdf_view_construct (gpdf_view));
+	widget_class->button_press_event = gpdf_view_button_press_event;
+	widget_class->button_release_event = gpdf_view_button_release_event;
+	widget_class->motion_notify_event = gpdf_view_motion_notify_event;
+	widget_class->key_press_event = gpdf_view_key_press_event;
+
+	g_object_class_install_property (
+		object_class, PROP_CONTROL,
+		g_param_spec_object (
+			"control",
+			"Parent control",
+			"Parent control",
+			GPDF_TYPE_CONTROL, 
+		        (GParamFlags)(G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
+
+	g_object_class_install_property (
+		object_class, PROP_PDFDOC,
+		g_param_spec_pointer (
+			"pdf_doc",
+			"PDF Document",
+			"PDF Document",
+		        (GParamFlags)(G_PARAM_READABLE | G_PARAM_WRITABLE)));
+
+	gpdf_view_signals [ZOOM_CHANGED_SIGNAL] = g_signal_new (
+		"zoom_changed",
+		G_TYPE_FROM_CLASS (object_class),
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (GPdfViewClass, zoom_changed),
+		NULL, NULL,
+		gpdf_marshal_VOID__DOUBLE,
+		G_TYPE_NONE, 1, G_TYPE_DOUBLE);
+
+	gpdf_view_signals [PAGE_CHANGED_SIGNAL] = g_signal_new (
+		"page_changed",
+		G_TYPE_FROM_CLASS (object_class),
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (GPdfViewClass, page_changed),
+		NULL, NULL,
+		gpdf_marshal_VOID__INT,
+		G_TYPE_NONE, 1, G_TYPE_INT);
+
+	gpdf_view_signals [CLOSE_REQUESTED_SIGNAL] = g_signal_new (
+		"close_requested",
+		G_TYPE_FROM_CLASS (object_class),
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (GPdfViewClass, close_requested),
+		NULL, NULL,
+		gpdf_marshal_VOID__VOID,
+		G_TYPE_NONE, 0);
+
+	gpdf_view_signals [QUIT_REQUESTED_SIGNAL] = g_signal_new (
+		"quit_requested",
+		G_TYPE_FROM_CLASS (object_class),
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (GPdfViewClass, quit_requested),
+		NULL, NULL,
+		gpdf_marshal_VOID__VOID,
+		G_TYPE_NONE, 0);
+}
+
+static void
+ggv_document_interface_init (GgvDocumentClass *klass, gpointer iface_data)
+{
+	klass->get_page_count = gpdf_view_get_page_count;
+	klass->get_page_names = gpdf_view_get_page_names;
+}
+
+static void
+gpdf_view_instance_init (GPdfView *gpdf_view)
+{
+	gpdf_view->priv = g_new0 (GPdfViewPrivate, 1);
 }
 
 static void
